@@ -9,9 +9,9 @@
 #include <QtCore/QDateTime>
 #include <Soprano/Vocabulary/RDF>
 
-#include <dms-copy/simpleresource.h>
+#include <nepomuk2/simpleresource.h>
 
-namespace Nepomuk {
+namespace Nepomuk2 {
 namespace NCAL {
 /**
  * A time entity. Conceived as a common superclass for NcalDateTime 
@@ -24,7 +24,7 @@ namespace NCAL {
 class NcalTimeEntity
 {
 public:
-    NcalTimeEntity(Nepomuk::SimpleResource* res)
+    NcalTimeEntity(Nepomuk2::SimpleResource* res)
       : m_res(res)
     {}
 
@@ -34,7 +34,7 @@ protected:
     virtual QUrl resourceType() const { return QUrl::fromEncoded("http://www.semanticdesktop.org/ontologies/2007/04/02/ncal#NcalTimeEntity", QUrl::StrictMode); }
 
 private:
-    Nepomuk::SimpleResource* m_res;
+    Nepomuk2::SimpleResource* m_res;
 };
 }
 }
