@@ -56,6 +56,9 @@ public:
 
   void kill();
 
+Q_SIGNALS:
+  void status( int status, const QString &message = QString() );
+
 protected:
   virtual void doStart( KIMAP::Session *session ) = 0;
 
@@ -72,6 +75,7 @@ protected:
 
   Akonadi::Collection collection() const;
   Akonadi::Item item() const;
+  Akonadi::Item::List items() const;
 
   Akonadi::Collection parentCollection() const;
 
@@ -79,6 +83,8 @@ protected:
   Akonadi::Collection targetCollection() const;
 
   QSet<QByteArray> parts() const;
+  QSet<QByteArray> addedFlags() const;
+  QSet<QByteArray> removedFlags() const;
 
   QString rootRemoteId() const;
   QString mailBoxForCollection( const Akonadi::Collection &collection ) const;
@@ -96,6 +102,7 @@ protected:
   void itemsRetrievalDone();
 
   void changeCommitted( const Akonadi::Item &item );
+  void changesCommitted( const Akonadi::Item::List &items );
 
   void collectionsRetrieved( const Akonadi::Collection::List &collections );
 
@@ -109,7 +116,7 @@ protected:
   void emitPercent( int percent );
   void emitError( const QString &message );
   void emitWarning( const QString &message );
-  
+
 
   void synchronizeCollectionTree();
 
